<?php

namespace IPS\forumfortress\tasks;

use IPS\forumfortress\Api\Client;
use IPS\Task;

if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( $_SERVER['SERVER_PROTOCOL'] ?? 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class hourlySync extends Task
{
	public function execute() : mixed
	{
		Client::hourlySync();

		return NULL;
	}
}
